==> Net-DRI-0.96_01.tar.gz: Net-DRI-0.96_01/lib/Net/DRI/Protocol/EPP/Extensions/CentralNic.pm <==
## Domain Registry Interface, CentralNic EPP extensions
## (http://labs.centralnic.com/epp/ext/)
##
## Copyright (c) 2007-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
##
## This file is part of Net::DRI
##
## Net::DRI is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## See the LICENSE file that comes with this distribution for more details.
#
# 
#
####################################################################################################

package Net::DRI::Protocol::EPP::Extensions::CentralNic;

use strict;
use warnings;

use base qw/Net::DRI::Protocol::EPP/;

our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };

=pod

=head1 NAME

Net::DRI::Protocol::EPP::Extensions::CentralNic - CentralNic EPP extensions for Net::DRI

=head1 DESCRIPTION

Please see the README file for details.

=head1 SUPPORT

For now, support questions should be sent to:

E<lt>netdri@dotandco.comE<gt>

Please also see the SUPPORT file in the distribution.

=head1 SEE ALSO

E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>

=head1 AUTHOR

Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>

=head1 COPYRIGHT

Copyright (c) 2007-2011 Patrick Mevzek <netdri@dotandco.com>.
All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

See the LICENSE file that comes with this distribution for more details.

=cut

####################################################################################################

sub setup
{
 my ($self,$rp)=@_;
 $self->ns({ttl => ['urn:centralnic:params:xml:ns:ttl-1.0','ttl-1.0.xsd'],
            wf  => ['urn:centralnic:params:xml:ns:wf-1.0','wf-1.0.xsd'],
          });
 $self->capabilities('domain_update','ttl',['set']);
 $self->capabilities('domain_update','web_forwarding',['set']);
 return;
}

sub default_extensions { return qw/CentralNic::TTL CentralNic::WebForwarding CentralNic::Release SecDNS VeriSign::Sync/; }

####################################################################################################
1;

==> Net-DRI-0.96_08.tar.gz: Net-DRI-0.96_08/lib/Net/DRI/Protocol/EPP/Extensions/CentralNic.pm <==
## Domain Registry Interface, CentralNic EPP extensions
## (http://labs.centralnic.com/epp/ext/)
##
## Copyright (c) 2007-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
##
## This file is part of Net::DRI
##
## Net::DRI is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## See the LICENSE file that comes with this distribution for more details.
####################################################################################################

package Net::DRI::Protocol::EPP::Extensions::CentralNic;

use strict;
use warnings;

use base qw/Net::DRI::Protocol::EPP/;

=pod

=head1 NAME

Net::DRI::Protocol::EPP::Extensions::CentralNic - CentralNic EPP extensions for Net::DRI

=head1 DESCRIPTION

Please see the README file for details.

=head1 SUPPORT

For now, support questions should be sent to:

E<lt>netdri@dotandco.comE<gt>

Please also see the SUPPORT file in the distribution.

=head1 SEE ALSO

E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>

=head1 AUTHOR

Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>

=head1 COPYRIGHT

Copyright (c) 2007-2011 Patrick Mevzek <netdri@dotandco.com>.
All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

See the LICENSE file that comes with this distribution for more details.

=cut

####################################################################################################

sub setup
{
 my ($self,$rp)=@_;
 $self->ns({ttl => ['urn:centralnic:params:xml:ns:ttl-1.0','ttl-1.0.xsd'],
            wf  => ['urn:centralnic:params:xml:ns:wf-1.0','wf-1.0.xsd'],
          });
 $self->capabilities('domain_update','ttl',['set']);
 $self->capabilities('domain_update','web_forwarding',['set']);
 return;
}

sub default_extensions { return qw/CentralNic::TTL CentralNic::WebForwarding CentralNic::Release CentralNic::Pricing SecDNS VeriSign::Sync/; }

####################################################################################################
1;
